==> mono-2.6.4.tar.bz2: mono-2.6.4/mcs/class/System.Data/System.Data/MissingPrimaryKeyException.cs <==
//
// System.Data.MissingPrimaryKeyException.cs
//
// Author: Duncan Mak  (duncan@ximian.com)
//
// (C) Ximian, Inc.

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Globalization;
using System.Runtime.Serialization;

namespace System.Data
{
	[Serializable]
	public class MissingPrimaryKeyException : DataException
	{
		public MissingPrimaryKeyException ()
			: base (Locale.GetText ("This table has no primary key"))
		{
		}

		public MissingPrimaryKeyException (string s)
			: base (s)
		{
		}

#if NET_2_0
		public MissingPrimaryKeyException (string message, Exception inner)
			: base (message, inner)
		{
		}
#endif

		protected MissingPrimaryKeyException (SerializationInfo info, StreamingContext context)
			: base (info, context)
		{
		}
	}
}

==> mono-4.0.1.28.tar.bz2: mono-4.0.1/mcs/class/System.Data/System.Data/MissingPrimaryKeyException.cs <==
//
// System.Data.MissingPrimaryKeyException.cs
//
// Author: Duncan Mak  (duncan@ximian.com)
//
// (C) Ximian, Inc.

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Globalization;
using System.Runtime.Serialization;

namespace System.Data
{
	[Serializable]
	public class MissingPrimaryKeyException : DataException
	{
		public MissingPrimaryKeyException ()
			: base (Locale.GetText ("This table has no primary key"))
		{
		}

		public MissingPrimaryKeyException (string s)
			: base (s)
		{
		}

		public MissingPrimaryKeyException (string message, Exception innerException)
			: base (message, innerException)
		{
		}

		protected MissingPrimaryKeyException (SerializationInfo info, StreamingContext context)
			: base (info, context)
		{
		}
	}
}
